@@ -109,7 +109,7 @@ class Chunk:
             section = self.get_section(section)
         if section is None:
             return
-        return tuple(Block.from_palette(i) for i in section['Palette'])
+        return tuple(Block.from_palette(i) for i in section['block_states']['palette'])
         
 
     def get_block(self, x: int, y: int, z: int, section: Union[int, nbt.TAG_Compound]=None, force_new: bool=False) -> Union[Block, OldBlock]:
@@ -170,25 +170,25 @@ class Chunk:
                 return block
 
         # If its an empty section its most likely an air block
-        if section is None or 'BlockStates' not in section:
+        if section is None or 'block_states' not in section:
             return Block.from_name('minecraft:air')
 
-        # Number of bits each block is on BlockStates
+        # Number of bits each block is on block_states
         # Cannot be lower than 4
-        bits = max((len(section['Palette']) - 1).bit_length(), 4)
+        bits = max((len(section['block_states']['palette']) - 1).bit_length(), 4)
 
         # Get index on the block list with the order YZX
         index = y * 16*16 + z * 16 + x
 
-        # BlockStates is an array of 64 bit numbers
+        # block_states is an array of 64 bit numbers
         # that holds the blocks index on the palette list
-        states = section['BlockStates'].value
+        states = section['block_states']['data'].value
 
-        # in 20w17a and newer blocks cannot occupy more than one element on the BlockStates array
+        # in 20w17a and newer blocks cannot occupy more than one element on the block_states array
         stretches = self.version is None or self.version < _VERSION_20w17a
         # stretches = True
 
-        # get location in the BlockStates array via the index
+        # get location in the block_states array via the index
         if stretches:
             state = index * bits // 64
         else:
@@ -228,7 +228,7 @@ class Chunk:
         # which are the palette index
         palette_id = shifted_data & 2**bits - 1
 
-        block = section['Palette'][palette_id]
+        block = section['block_states']['palette'][palette_id]
         return Block.from_palette(block)
 
     def stream_blocks(self, index: int=0, section: Union[int, nbt.TAG_Compound]=None, force_new: bool=False) -> Generator[Block, None, None]:
@@ -289,14 +289,14 @@ class Chunk:
                 index += 1
             return
 
-        if section is None or 'BlockStates' not in section:
+        if section is None or 'block_states' not in section:
             air = Block.from_name('minecraft:air')
             for i in range(4096):
                 yield air
             return
 
-        states = section['BlockStates'].value
-        palette = section['Palette']
+        states = section['block_states']['data'].value
+        palette = section['block_states']['palette']
 
         bits = max((len(palette) - 1).bit_length(), 4)
 
